@@ -65,6 +65,7 @@ public:
 
         VPHAL_HDR_LUT_MODE globalLutMode      = VPHAL_HDR_LUT_MODE_NONE;  //!< Global LUT mode control for debugging purpose
         bool               gpuGenerate3DLUT   = false;                        //!< Flag for per frame GPU generation of 3DLUT
+        bool               isExternal3DLutSupport  = true;
         bool               disableAutoMode    = false;
         bool               clearVideoViewMode = false;
         uint32_t           splitFramePortions = 1;
@@ -157,6 +158,11 @@ public:
         return m_ctrlVal.gpuGenerate3DLUT;
     }
 
+    bool IsExternal3DLutSupport()
+    {
+        return m_ctrlVal.isExternal3DLutSupport;
+    }
+
     bool IsDisableAutoMode()
     {
         return m_ctrlVal.disableAutoMode;
